// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package config

type LogConfig struct {
	Path       string
	Level      string
	MaxSize    int
	MaxBackups int
	MaxAge     int
	Stacktrace bool
}

type MysqlConfig struct {
	User     string
	Password string
	Addr     string
	DB       string
	Charset  string
	MaxIdle  int
	MaxConn  int
	LogMode  bool
}

type RedisConfig struct {
	Addrs        []string
	Password     string
	DB           int
	PoolSize     int
	MinIdleConns int
	MaxRetries   int
	Cluster      bool
}

type ElasticConfig struct {
	Addrs []string
	Sniff bool
}

type ThirdPartNode struct {
	Host      string
	AppKey    string
	AppSecret string
}

type RongLianNode struct {
	City                     string
	RongLianSid              string
	RongLianToken            string
	RongLianServerIp         string
	RongLianServerPort       string
	RongLianSoftVersion      string
	RongLianAppId            string
	VcodeTemplateId          int
	AlarmTemplateId          int
	CompanyVerifyTemplateId  int
	ProviderVerifyTemplateId int
}

type MojiNode struct {
	MojiAppCode     string
	ConditionUrl    string
	EnviromentUrl   string
	ForecastUrl     string
	DefaultProvince string
	DefaultRegion   string
}

type ProvincialNode struct {
	Account string
	Password string
	AppKey string
	AppSecret string

	LoginApi string
	ProjectCodeApi string
	ProjectUploadApi string
	ProvincialVerifyApi string
	DustDeviceUploadApi string
	DustDataUploadApi string
}

type ThirdPartConfig struct {
	PartName ThirdPartNode
	RongLian RongLianNode
	Moji     MojiNode
	Provincial ProvincialNode
	MailHost string
	MailUser string
	MailPass string
}

type RPCNode struct {
	ServiceName   string
	ServicePort   int
	ServiceIp     string
	MysqlDb       string
	RedisDb       int
	LogLevel      string
	LogStacktrace bool
}

type KeepaliveConfig struct {
	ClientTime    int
	ClientTimeout int

	ServerTime     int
	ServerTimeout  int
	ServerMiniTime int
}

type RPCConfig struct {
	Keepalive       KeepaliveConfig
	SmartProvincial RPCNode
}

type InfluxdbConfig struct {
	Addr     string
	Username string
	Password string
}

type Configure struct {
	// 基础配置
	K8s           bool
	RunMode       string
	Log           LogConfig
	EnterpriseUrl string
	SupplierUrl   string

	// 按需配置
	Mysql      MysqlConfig
	Redis      RedisConfig
	Elastic    ElasticConfig
	ThirdParty ThirdPartConfig
	Influxdb   InfluxdbConfig

	// 所要启用的服务
	Rpc RPCConfig
}
