package provincial_department

import (
	"context"
	"encoding/json"
	"fmt"
	"github.com/tidwall/gjson"
	"go.uber.org/zap"
	"smart-provincial/errors"
	"smart-provincial/pb/v1"
	"smart-provincial/thirdparty"
	"strings"
	"smart-provincial/parser"
	"github.com/jaryhe/gopkgs/logger"
)

func ProvincialPostDustData(ctx context.Context, req *v1.ProvincialPostDustDataRequest)(reply *v1.ProvincialPostDustDataReply, err error) {
	token, err := Login()
	if err != nil {
		return nil, err
	}
	if len(req.Datas) == 0 {
		return &v1.ProvincialPostDustDataReply{}, nil
	}


	/*
	param := map[string]interface{}{
		"Code":req.Code,
		"Name":req.Name,
		"DeviceID":req.DeviceId,
		"MonitoringTime":req.MonitoringTime,
		"SaveTime":req.SaveTime,
		"PM10Value":req.Pm10Value,
		"PM25Value":req.Pm25Value,
		"Voice":req.Voice,
		"SprayStatus":req.SprayStatus,

	}*/
	datas := []map[string]interface{}{}


	for _, v := range req.Datas {
		data := map[string]interface{}{
			"MonitoringTime":v.MonitoringTime,
			"SaveTime":v.SaveTime,
			"FValue":fmt.Sprintf("%f", v.Pm25Value),
		}
		datas = append(datas, data)
	}

	param := map[string]interface{}{
		"SBID":req.Datas[0].DeviceId,
		"FCode":"PM2.5",
		"Type":req.Datas[0].Type,
		"DATA": datas,
	}
	bytes, err := thirdparty.ProvincialPost(parser.Conf.ThirdParty.Provincial.DustDataUploadApi, token, param)
	fmt.Printf("provincial dust data: %s,%v\n", bytes, err)
	if err != nil {
		s, _ := json.Marshal(param)
		logger.Error("thirdpary provincial dust data",
			zap.String("call", parser.Conf.ThirdParty.Provincial.DustDataUploadApi),
			zap.String("param", string(s)),
			zap.String("error", err.Error()))
		return nil, errors.ProvincialDustDataUploadError
	}
	ack := gjson.GetBytes(bytes, "ack_code").String()
	if strings.ToUpper(ack) != "SUCCESS" {
		s, _ := json.Marshal(param)
		logger.Error("thirdpary provincial dust data",
			zap.String("call", parser.Conf.ThirdParty.Provincial.DustDataUploadApi),
			zap.String("param", string(s)),
			zap.String("error",string(bytes)))
		return nil, errors.ProvincialDustDataUploadError
	}
	reply = &v1.ProvincialPostDustDataReply{}

	return reply, nil
}
