package provincial_department

import (
	"encoding/json"
	"github.com/jaryhe/gopkgs/cache"
	"github.com/tidwall/gjson"
	"go.uber.org/zap"
	"fmt"
	"smart-provincial/parser"
	"smart-provincial/thirdparty"
	"github.com/jaryhe/gopkgs/logger"
	"smart-provincial/errors"
	"strconv"
	"strings"
)

const provincialKey = "provincial_token"
func Login() (string, error) {
	if token := getTokenFromLocal(); token != "" {
		return token, nil
	}
	var param = map[string]interface{}{
		"account":parser.Conf.ThirdParty.Provincial.Account,
		"password":parser.Conf.ThirdParty.Provincial.Password,
		"app_key":parser.Conf.ThirdParty.Provincial.AppKey,
		"app_secret":parser.Conf.ThirdParty.Provincial.AppSecret,
	}
	bytes, err := thirdparty.ProvincialPost(parser.Conf.ThirdParty.Provincial.LoginApi, "", param)
	fmt.Printf("provincial login %s,%v\n", bytes, err)
	if err != nil {
		s,_ := json.Marshal(param)
		logger.Error("thirdpary provincial login",
			zap.String("call", parser.Conf.ThirdParty.Provincial.LoginApi),
			zap.String("params", string(s)),
			zap.String("error", err.Error()))
		return "", errors.ProvincialLoginError
	}
	ack := gjson.GetBytes(bytes, "ack_code").String()
	if strings.ToUpper(ack) != "SUCCESS" {
		s,_ := json.Marshal(param)
		logger.Error("thirdpary provincial login",
			zap.String("call", parser.Conf.ThirdParty.Provincial.LoginApi),
			zap.String("params", string(s)),
			zap.String("error",string(bytes)))
		return "", errors.ProvincialLoginError
	}
	token := gjson.GetBytes(bytes, "access_token").String()
	if token == "" {
		s,_ := json.Marshal(param)
		logger.Error("thirdpary provincial login",
			zap.String("call", parser.Conf.ThirdParty.Provincial.LoginApi),
			zap.String("params", string(s)),
			zap.String("error",string(bytes)))
		return "", errors.ProvincialLoginError
	}

	expire := gjson.GetBytes(bytes, "expires_in").String()
	expireInt, _ := strconv.Atoi(expire)

	if expireInt == 0 {
		expireInt = 60
	} else if expireInt > 30 {
		expireInt -= 30
	}

	cache.Redis().SetNxEx(provincialKey, token, int64(expireInt))
	return token, nil

}

func getTokenFromLocal() string {
	token, _:= cache.Redis().Get(provincialKey)
	return token
}
